.. octavia-specs documentation master file

====
Main
====

Getting started
---------------

.. toctree::
   :maxdepth: 1

   main/glossary.rst

For developers
--------------

.. toctree::
   :maxdepth: 1

   main/CONSTITUTION.rst
   main/HACKING.rst

====
APIs
====

.. toctree::
   :glob:
   :maxdepth: 1

   api/*

====================
Design Documentation
====================

Version 0.5
-----------

.. toctree::
   :glob:
   :maxdepth: 1

   design/version0.5/*

======================
Project Specifications
======================

Version 0.5
-----------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.5/*

Version 1
---------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1/*

==================
Indices and tables
==================

* :ref:`search`
